<?php

namespace Litecms\MatrixLevel\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\MatrixLevel\Http\Requests\MatrixLevelRequest;
use Litecms\MatrixLevel\Interfaces\MatrixLevelRepositoryInterface;
use Litecms\MatrixLevel\Models\MatrixLevel;

/**
 * Resource controller class for matrix_level.
 */
class MatrixLevelResourceController extends BaseController
{

    /**
     * Initialize matrix_level resource controller.
     *
     * @param type MatrixLevelRepositoryInterface $matrix_level
     *
     * @return null
     */
    public function __construct(MatrixLevelRepositoryInterface $matrix_level)
    {
        parent::__construct();
        $this->repository = $matrix_level;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\MatrixLevel\Repositories\Criteria\MatrixLevelResourceCriteria::class);
    }

    /**
     * Display a list of matrix_level.
     *
     * @return Response
     */
    public function index(MatrixLevelRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\MatrixLevel\Repositories\Presenter\MatrixLevelPresenter::class)
                ->$function();
        }

        $matrix_levels = $this->repository->paginate();

        return $this->response->title(trans('matrix_level::matrix_level.names'))
            ->view('matrix_level::matrix_level.index', true)
            ->data(compact('matrix_levels'))
            ->output();
    }

    /**
     * Display matrix_level.
     *
     * @param Request $request
     * @param Model   $matrix_level
     *
     * @return Response
     */
    public function show(MatrixLevelRequest $request, MatrixLevel $matrix_level)
    {

        if ($matrix_level->exists) {
            $view = 'matrix_level::matrix_level.show';
        } else {
            $view = 'matrix_level::matrix_level.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('matrix_level::matrix_level.name'))
            ->data(compact('matrix_level'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new matrix_level.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(MatrixLevelRequest $request)
    {

        $matrix_level = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('matrix_level::matrix_level.name')) 
            ->view('matrix_level::matrix_level.create', true) 
            ->data(compact('matrix_level'))
            ->output();
    }

    /**
     * Create new matrix_level.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(MatrixLevelRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $matrix_level                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('matrix_level::matrix_level.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('matrix_level/matrix_level/' . $matrix_level->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/matrix_level/matrix_level'))
                ->redirect();
        }

    }

    /**
     * Show matrix_level for editing.
     *
     * @param Request $request
     * @param Model   $matrix_level
     *
     * @return Response
     */
    public function edit(MatrixLevelRequest $request, MatrixLevel $matrix_level)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('matrix_level::matrix_level.name'))
            ->view('matrix_level::matrix_level.edit', true)
            ->data(compact('matrix_level'))
            ->output();
    }

    /**
     * Update the matrix_level.
     *
     * @param Request $request
     * @param Model   $matrix_level
     *
     * @return Response
     */
    public function update(MatrixLevelRequest $request, MatrixLevel $matrix_level)
    {
        try {
            $attributes = $request->all();

            $matrix_level->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('matrix_level::matrix_level.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('matrix_level/matrix_level/' . $matrix_level->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('matrix_level/matrix_level/' . $matrix_level->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the matrix_level.
     *
     * @param Model   $matrix_level
     *
     * @return Response
     */
    public function destroy(MatrixLevelRequest $request, MatrixLevel $matrix_level)
    {
        try {

            $matrix_level->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('matrix_level::matrix_level.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('matrix_level/matrix_level/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('matrix_level/matrix_level/' . $matrix_level->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple matrix_level.
     *
     * @param Model   $matrix_level
     *
     * @return Response
     */
    public function delete(MatrixLevelRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('matrix_level::matrix_level.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('matrix_level/matrix_level'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/matrix_level/matrix_level'))
                ->redirect();
        }

    }

    /**
     * Restore deleted matrix_levels.
     *
     * @param Model   $matrix_level
     *
     * @return Response
     */
    public function restore(MatrixLevelRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('matrix_level::matrix_level.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/matrix_level/matrix_level'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/matrix_level/matrix_level/'))
                ->redirect();
        }

    }

}
